# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/problem_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/problem_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import problem_pb2 as eolymp_dot_judge_dot_problem__pb2
from eolymp.judge import template_pb2 as eolymp_dot_judge_dot_template__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/judge/problem_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/judge/problem.proto\x1a\x1b\x65olymp/judge/template.proto\x1a\x1c\x65olymp/runtime/runtime.proto\"\x7f\n\x12ImportProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\")\n\x13ImportProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\":\n\x10SyncProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x13\n\x11SyncProblemOutput\"\xe5\x01\n\x12UpdateProblemInput\x12\x35\n\x05patch\x18\x03 \x03(\x0e\x32&.eolymp.judge.UpdateProblemInput.Patch\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12&\n\x07problem\x18\x04 \x01(\x0b\x32\x15.eolymp.judge.Problem\"H\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05INDEX\x10\x01\x12\x10\n\x0cSUBMIT_LIMIT\x10\x02\x12\x19\n\x15SCORE_BY_BEST_TESTSET\x10\x03\"\x15\n\x13UpdateProblemOutput\"<\n\x12\x44\x65leteProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"E\n\x11ListProblemsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.judge.Problem\">\n\x14\x44\x65scribeProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Problem\"X\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0btemplate_id\x18\x03 \x01(\t\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.judge.Template\"R\n\x17LookupCodeTemplateInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.judge.Template\"=\n\x13ListStatementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"U\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.judge.Problem.Statement\">\n\x14ListAttachmentsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"W\n\x15ListAttachmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.judge.Problem.Attachment\";\n\x11ListExamplesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"N\n\x12ListExamplesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Problem.Test\";\n\x11ListRuntimesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"K\n\x12ListRuntimesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime2\xf4\x0f\n\x0eProblemService\x12\x91\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x0b\"\t/problems\x12\x9d\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/problems/{problem_id}/sync\x12\x9e\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x18\"\x16/problems/{problem_id}\x12\x8d\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x0b\x12\t/problems\x12\xa4\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"H\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x18\x12\x16/problems/{problem_id}\x12\x9e\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x18*\x16/problems/{problem_id}\x12\xbc\x01\n\x12LookupCodeTemplate\x12%.eolymp.judge.LookupCodeTemplateInput\x1a&.eolymp.judge.LookupCodeTemplateOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02(\x12&/problems/{problem_id}/lookup-template\x12\xca\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"_\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x30\x12./problems/{problem_id}/templates/{template_id}\x12\xab\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02#\x12!/problems/{problem_id}/statements\x12\xaf\x01\n\x0fListAttachments\x12\".eolymp.judge.ListAttachmentsInput\x1a#.eolymp.judge.ListAttachmentsOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02$\x12\"/problems/{problem_id}/attachments\x12\xa3\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/examples\x12\xa2\x01\n\x0cListRuntimes\x12\x1f.eolymp.judge.ListRuntimesInput\x1a .eolymp.judge.ListRuntimesOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x19\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02 \x12\x1e/problems/{problem_id}/runtimeB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.problem_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PROBLEMSERVICE'].methods_by_name['ImportProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ImportProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\013\"\t/problems'
  _globals['_PROBLEMSERVICE'].methods_by_name['SyncProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['SyncProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\035\"\033/problems/{problem_id}/sync'
  _globals['_PROBLEMSERVICE'].methods_by_name['UpdateProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['UpdateProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\030\"\026/problems/{problem_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListProblems']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListProblems']._serialized_options = b'\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\013\022\t/problems'
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeProblem']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\030\022\026/problems/{problem_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['DeleteProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DeleteProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\030*\026/problems/{problem_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['LookupCodeTemplate']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['LookupCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002(\022&/problems/{problem_id}/lookup-template'
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeCodeTemplate']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0020\022./problems/{problem_id}/templates/{template_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListStatements']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListStatements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002#\022!/problems/{problem_id}/statements'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListAttachments']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListAttachments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002$\022\"/problems/{problem_id}/attachments'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListExamples']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListExamples']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002!\022\037/problems/{problem_id}/examples'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListRuntimes']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListRuntimes']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\031\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002 \022\036/problems/{problem_id}/runtime'
  _globals['_IMPORTPROBLEMINPUT']._serialized_start=238
  _globals['_IMPORTPROBLEMINPUT']._serialized_end=365
  _globals['_IMPORTPROBLEMOUTPUT']._serialized_start=367
  _globals['_IMPORTPROBLEMOUTPUT']._serialized_end=408
  _globals['_SYNCPROBLEMINPUT']._serialized_start=410
  _globals['_SYNCPROBLEMINPUT']._serialized_end=468
  _globals['_SYNCPROBLEMOUTPUT']._serialized_start=470
  _globals['_SYNCPROBLEMOUTPUT']._serialized_end=489
  _globals['_UPDATEPROBLEMINPUT']._serialized_start=492
  _globals['_UPDATEPROBLEMINPUT']._serialized_end=721
  _globals['_UPDATEPROBLEMINPUT_PATCH']._serialized_start=649
  _globals['_UPDATEPROBLEMINPUT_PATCH']._serialized_end=721
  _globals['_UPDATEPROBLEMOUTPUT']._serialized_start=723
  _globals['_UPDATEPROBLEMOUTPUT']._serialized_end=744
  _globals['_DELETEPROBLEMINPUT']._serialized_start=746
  _globals['_DELETEPROBLEMINPUT']._serialized_end=806
  _globals['_DELETEPROBLEMOUTPUT']._serialized_start=808
  _globals['_DELETEPROBLEMOUTPUT']._serialized_end=829
  _globals['_LISTPROBLEMSINPUT']._serialized_start=831
  _globals['_LISTPROBLEMSINPUT']._serialized_end=900
  _globals['_LISTPROBLEMSOUTPUT']._serialized_start=902
  _globals['_LISTPROBLEMSOUTPUT']._serialized_end=975
  _globals['_DESCRIBEPROBLEMINPUT']._serialized_start=977
  _globals['_DESCRIBEPROBLEMINPUT']._serialized_end=1039
  _globals['_DESCRIBEPROBLEMOUTPUT']._serialized_start=1041
  _globals['_DESCRIBEPROBLEMOUTPUT']._serialized_end=1104
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_start=1106
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_end=1194
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_start=1196
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_end=1266
  _globals['_LOOKUPCODETEMPLATEINPUT']._serialized_start=1268
  _globals['_LOOKUPCODETEMPLATEINPUT']._serialized_end=1350
  _globals['_LOOKUPCODETEMPLATEOUTPUT']._serialized_start=1352
  _globals['_LOOKUPCODETEMPLATEOUTPUT']._serialized_end=1420
  _globals['_LISTSTATEMENTSINPUT']._serialized_start=1422
  _globals['_LISTSTATEMENTSINPUT']._serialized_end=1483
  _globals['_LISTSTATEMENTSOUTPUT']._serialized_start=1485
  _globals['_LISTSTATEMENTSOUTPUT']._serialized_end=1570
  _globals['_LISTATTACHMENTSINPUT']._serialized_start=1572
  _globals['_LISTATTACHMENTSINPUT']._serialized_end=1634
  _globals['_LISTATTACHMENTSOUTPUT']._serialized_start=1636
  _globals['_LISTATTACHMENTSOUTPUT']._serialized_end=1723
  _globals['_LISTEXAMPLESINPUT']._serialized_start=1725
  _globals['_LISTEXAMPLESINPUT']._serialized_end=1784
  _globals['_LISTEXAMPLESOUTPUT']._serialized_start=1786
  _globals['_LISTEXAMPLESOUTPUT']._serialized_end=1864
  _globals['_LISTRUNTIMESINPUT']._serialized_start=1866
  _globals['_LISTRUNTIMESINPUT']._serialized_end=1925
  _globals['_LISTRUNTIMESOUTPUT']._serialized_start=1927
  _globals['_LISTRUNTIMESOUTPUT']._serialized_end=2002
  _globals['_PROBLEMSERVICE']._serialized_start=2005
  _globals['_PROBLEMSERVICE']._serialized_end=4041
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/file.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/executor/file.proto\x12\x0f\x65olymp.executor\"(\n\x04\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsource_url\x18\x03 \x01(\tB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_FILE']._serialized_start=47
  _globals['_FILE']._serialized_end=87
# @@protoc_insertion_point(module_scope)
